;*****************************************************************************
;  Jmenu Menu System for Paradox 
;
;  Author - Jerry Sayre
;  Date   - October 1991
; 
;  To Start the Demonstration, simply play "Demo".  The Jmenu library will
;  be built automatically and will not self-destruct.
;
;  The following files are included in this .Zip
;
;    File Name   Description 
;    ---------   ------------------------------------------------
;
;    BLDLIB.SC - Script that builds Jmenu library.
;    DEMO.SC   - Black Book Applications that demonstrates the use
;                of Jmenu.
;    HELP.DB   - Online Help Database.
;    NAMES.DB  - Black Book Database.
;    NAMES.F   - Black Book Database Form.
;    MENU.DB   - Menu Items Database.
;
;  The following Procedures are contained within the Jmenu Library 
;
;  Draw_Menu
;  Make_Jmenu      (*)
;  Header          (*)
;  Footer          (*)
;  Jmenu_Help
;  Jmenu_Draw_Help
;
;  (*) These procedure are called by you.  The remaining procedures are
;      only called from within the library.
;  
;  This software may be freely distributed as long as all the above 
;  files are included and remain unmodified.
;
;  If you want the registered version or some help implementing this menu
;  system send a check or money order 
;  for $10 to:
;
;     Jerry Sayre / ICO Shar&Assoc.
;     210 East 1st
;     McCook NE 69001
;
;  The registered version of the software has a large number of other
;  tools included with it (Generalized data entry procedures, Exploding
;  box input areas, etc...).
;
;  I would appreciate any comments, positive or otherwise. :)
;
;  Genie : J.Sayre2
;
;*****************************************************************************
;
;Check for the required library files
;
If not isfile("Jmenu.Lib") then
  if isfile("Bldlib.Sc") then
    Message "Building Library..."
    Cursor off
    Canvas off
    Play "BldLib"
    Canvas on
    Cursor Normal
  else
    Cursor off
    Message "Can't Find Script BldLib < Press any Key >..."
    Nul_Var = Getchar()
    Return
  endif
endif

Clear
PaintCanvas  Attribute 112 
             0,0,24,79

; AutoLib = "Jmenu"
; Either Set the AutoLib Varible to "Jmenu" or use the following Readlib:
 
  Readlib "Jmenu" Draw_Menu, Make_Jmenu, Header, Footer, Jmenu_Help,
                  Jmenu_Draw_Help

; The following variables are used by the Jmenu Library to Generate help
; screens and also to let the library know about it's environment.
; The Variables are:
;
;   HelpTable        -  This is the Table that contains the current menu's
;                       help screen. You don't have to define this variable.
;
;   Shadow_Color     -  This is the Style Attribute you want the shadow under
;                       the box to be.  If you do not want a shadow set the
;                       variable to your background color. You don't have
;                       to define this variable.
;
;   Background_Color -  This is the Background color that you have set for
;                       your application.  It is used to remove the help
;                       screen.
;

HelpTable        = "Help"
Shadow_Color     = 0
Background_Color = 112

Default_Menu_Choice = 1

While (True)

   Canvas off

   ;*************************************************************************
   ;
   ; Header and Footer are both called with the following 
   ; Parameters:
   ; 
   ; Header (Text to Center and Highlight, Style Attribute) 
   ; Footer (Text to Center and Highlight, Style Attribute)
   ;
   ;*************************************************************************

   Header("Little Black Book (F1-Help)",79)
   Footer("Demo and Libraries, Jerry Sayre (1990)",79)

   Canvas on

   ;*************************************************************************
   ;
   ; Make_Jmenu is called with the following Parameters:
   ;
   ; Return_Value = Make_Jmenu ( Table that contains menu elements (String),
   ;                             Field elements contained in (String),
   ;                             Row to display Menu on (Integer),
   ;                             Column to display Menu on (Integer),
   ;                             Default Menu Item (Integer) 
   ;                           )
   ;
   ; Make_Jmenu Returns an Integer that corresponds to the record
   ; number of the selected menu item.
   ; 
   ;************************************************************************

   Choice = Make_Jmenu("menu","menu item",2,3,95,Default_Menu_Choice)

   Switch

       Case (Choice = 1):            ; Add Name to Black Book

           View "Names"
           End
           if Recno() = 0 then
             Editkey
           Else
             Editkey
             Down
           Endif   
           Pickform "F"
           Wait Record
              Prompt "[F2] to Save and Exit","[F10] to Cancel Editing Session"
           Until "F2","F10"
           If Retval = "F2" then
              Do_it!
           Else
              Canceledit
           Endif
           Clearimage
           Clear

       Case (Choice = 2):            ; View Names in Black Book

           View "Names"
           If Recno() = 0 then
             Cursor off
             Message "No Names to View < Press any Key >..."
             Nul_Var = Getchar()
             Cursor Normal
           Else
             Pickform "F"
             Wait Table
               Prompt "[F2] to Exit"
             Until "F2"
             Clearimage
             Clear
           Endif
           
       Case (Choice = 3):            ; Edit Names in Black Book 

           View "Names"
           If Recno() = 0 then
             Cursor off
             Message "No Names to Edit < Press any Key >..."
             Nul_Var = Getchar()
             Cursor Normal
           Else
             Pickform "F"
             Editkey
             Wait Table
               Prompt "[F2] to Save and Exit","[F10] to Cancel Editing Session"
             Until "F2","F10"
             If Retval = "F2" then
                Do_it!
             Else
                Canceledit
             Endif
             Clearimage
             Clear
           Endif
            
       Case (Choice = 4):            ; Leave Black Book
         QuitLoop

   EndSwitch
   
   Default_Menu_Choice = Choice

EndWhile
Return
